#//-----------------------------------------------
#//TUSB-S02INx用Pythonサンプルプログラム
#// 処理関数等
#//
#//2024_05_02　株式会社タートル工業
#//Copyright (C) 2024 Turtle Industry Co.,Ltd.
#//-----------------------------------------------

import tkinter as tk
import tkinter.ttk as ttk
import threading
from tkinter import messagebox
import time

def ShowInfo(str):
    """文字列を表示する"""
    messagebox.showinfo("",str)

def GetLabel(master,text,relx,rely):
    """ラベルを作成する
    
    arguments:
    master      ----    配置ペアレント
    text        ----    表示する文字列
    relx        ----    X座標相対位置(左端)
    rely        ----    Y座標相対位置(上下中央)

    returns:
    Label       ----    生成されたラベルインスタンス
    """
    label = tk.Label(master,text=text)
    label.place(relx=relx,rely=rely,anchor=tk.W)
    return label

def GetButton(master,text,command,relw,relx,rely):
    """ボタンを作成する
    
    arguments:
    master      ----    配置ペアレント
    text        ----    ボタンに表示する文字列
    command     ----    ボタンが押された時に呼び出されるハンドラ関数
    relw        ----    表示幅(相対値)
    relx        ----    X座標相対位置(左右中央)
    rely        ----    Y座標相対位置(上下中央)

    returns:
    Button      ----    生成されたボタンインスタンス
    """
    button = tk.Button(master,text=text,command=command)
    button.place(relwidth=relw,relx=relx,rely=rely,anchor=tk.CENTER)
    return button

def GetComboBox(master,value,relw,relx,rely,command=None):
    """コンボボックスを作成する
    
    arguments:
    master      ----    配置ペアレント
    value       ----    コンボボックスに設定するデータリスト(又はタプル)
    relw        ----    表示幅(相対値)
    relx        ----    X座標相対位置(左端)
    rely        ----    Y座標相対位置(上下中央)
    command     ----    選択値が変更した時に呼び出される関数(引数としてイベントが渡される)

    returns:
    Combobox    ----    生成されたコンボボックスインスタンス
    """
    combobox = ttk.Combobox(master,value=value,state="readonly")
    combobox.bind("<<ComboboxSelected>>",command)
    combobox.place(relwidth=relw,relx=relx,rely=rely,anchor=tk.W)
    combobox.current(0)
    return combobox

# TUSB-S02INx専用ウィジット生成、操作

def GetLEDCanvas(master,relx,rely):
    """LEDランプイメージキャンバス作成
    
    arguments:
    master      ----    配置ペアレント
    relx        ----    X座標相対位置(左右中央)
    rely        ----    Y座標相対位置(上下中央)

    returns:
    Label       ----    生成されたキャンバスインスタンス
    """
    canvas = tk.Canvas(master,width=40,height=40)
    canvas.pack()
    canvas.place(relx=relx,rely=rely,anchor=tk.CENTER)
    return canvas

def SetLEDCanvas(canvas,on):
    """キャンバスにLEDの点灯、消灯イメージを表示

    arguments:
    canvas      ----    描画先キャンバスインスタンス
    on          ----    False:off True:on
    """
    if on == False:
        canvas.create_oval(4,4,39,39,fill="#800000",width=0)
        canvas.create_arc(8,8,35,35,extent=90,start=90,fill="Gray",outline="Gray",style=tk.ARC,width=6)
        canvas.create_arc(12,12,31,31,extent=60,start=110,fill="white",outline="white",style=tk.ARC,width=4)
    else:
        canvas.create_oval(4,4,39,39,fill="#F3ADB5",width=0)
        canvas.create_arc(8,8,35,35,extent=220,start=220,fill="Red",outline="Red",style=tk.ARC,width=6)
        canvas.create_arc(12,12,31,31,extent=60,start=110,fill="white",outline="white",style=tk.ARC,width=4)

# タイマースレッド管理クラス ////////////////////////////////////
#厳密なインターバルではない。関数処理が終わったら指定時間待つだけ。
#from builtins import function
class intTT():
    """タイマースレッド管理クラス
    厳密なインターバル処理ではない。
    関数処理が終わったら指定時間待って再度実行しつづるループ。
    """
    thread :threading.Thread = None # スレッドクラスオブジェクト
    thread_en : bool = None         # スレッド実行イネーブルフラグ
    call_func = None                # ループで実行する関数
    interval = None                 # ループの待ち時間

    def __init__(self,inttime,callf):
        """初期化"""
        self.interval = inttime # インターバルタイム
        self.call_func = callf  # 処理関数登録
    
    def ThreadF(self):
        """スレッド関数(ループ)"""
        while self.thread_en:
            self.call_func()
            time.sleep(self.interval)

    def Start(self):
        """スレッド開始処理"""
        if self.thread == None:
            self.thread_en = True
            self.thread = threading.Thread(target=self.ThreadF)
            self.thread.start()
    
    def Stop(self):
        """スレッド停止処理"""
        if self.thread_en != None:
            self.thread_en = False
            self.thread.join(self.interval+0.1)
            self.thread = None 
