#//-----------------------------------------------
#//TUSB-S02INx用ドライバアクセス用API
#//Python 用モジュール
#//
#//2024_05_02　株式会社タートル工業
#//Copyright (C) 2024 Turtle Industry Co.,Ltd.
#//-----------------------------------------------

from ctypes import *

tusbsindll = cdll.LoadLibrary("TUSBSIN.DLL")

tusbsindll.Tusbs02in_Device_Open.restype = c_short
tusbsindll.Tusbs02in_Device_Open.argtypes = (c_short,)
tusbsindll.Tusbs02in_Device_Close.restype = None
tusbsindll.Tusbs02in_Device_Close.argtypes = (c_short,)
tusbsindll.Tusbs02in_Read.restype = c_short
tusbsindll.Tusbs02in_Read.argtypes = (c_short,POINTER(c_ubyte),POINTER(c_ubyte))

#######  support functions (don not call directry from user codes)

def isint(n):
    return type(n) is int

def IsInRange(Val,Min,Max):
    if(isint(Val) == False ):   return False
    elif(Val < Min):            return False
    elif(Val > Max):            return False
    else:                       return True

def IsValidId(DevId):
    return IsInRange(DevId,0,15)

# def functions ------------------------------------

def Tusbs02in_Device_Open(DevId):
    """Open Device Connection
    
    Arguments:
    DevId           ----    DevIce ID 0~15
    
    Returns:
    int             ----    Result code
    """
    if(not IsValidId(DevId)):return 1
    return tusbsindll.Tusbs02in_Device_Open(DevId)

def Tusbs02in_Device_Close(DevId):
    """Close Device Connection

    Arguments:
    DevId           ----    Device ID 0~15

    Returns:
    None
    """
    if(not IsValidId(DevId)):return 2
    tusbsindll.Tusbs02in_Device_Close(DevId)

def Tusbs02in_Read(DevId):
    """Read Input
    
    Arguments:
    DevId           ----    Device ID 0~15

    Returns:
    int,            ----    Result code
    int,            ----    Input 1 Data
    int,            ----    Input 2 Data
    """
    if(not IsValidId(DevId)):return 2
    Data1 = c_ubyte()
    Data2 = c_ubyte()
    ret = tusbsindll.Tusbs02in_Read(DevId,byref(Data1),byref(Data2))
    if ret == 0:
        return 0,Data1.value,Data2.value
    else:
        return ret,None,None
    
#戻り値用エラーメッセージ
ErrStrDic = {
            0:"正常終了しました",
            1:"ID番号が不正です",
            2:"ドライバがインストールされていません",
            3:"すでにデバイスはオープンされています",
            4:"接続されている台数が多すぎます",
            5:"オープンできませんでした",
            6:"デバイスがみつかりません",
            7:"オープンされていません",
            8:"パラメータエラーです",
            9:"USB通信エラーです"
}
def GetErrMessage(retcode):
    if( retcode in ErrStrDic):
        return ErrStrDic[retcode]
    else:
        return "不明なエラーです"
