#//-----------------------------------------------
#//TUSB-S02INx用サンプルプログラム
#//Python 用モジュール
#//
#//2024_05_02　株式会社タートル工業
#//Copyright (C) 2024 Turtle Industry Co.,Ltd.
#//-----------------------------------------------
import TUSBSIN

from SpFuncs import *

DevId = None            # 開いているデバイスのID
mon_t = None            # タイマー管理クラスインスタンス

# Sub Functions -----------------------------

# Widgetの表示を設定する
# stat -> 'Close' , 'Open'
def WidgetState(stat):
    """Widgetの表示を設定する
    
    Arguments:
        stat        ----    設定状態 'Close' or 'Open'
    """
    EnClose = tk.NORMAL if( stat == 'Close' ) else tk.DISABLED
    EnOpen = tk.NORMAL if( stat == 'Open' ) else tk.DISABLED
    IDCmbb['state'] = EnClose
    if stat != 'Close' :
        form.protocol('WM_DELETE_WINDOW',lambda: 'pass' )
    else :
        form.protocol('WM_DELETE_WINDOW',lambda: form.destroy())

# Timer -------------------------------------
def Monitor():
    """入力状態モニタータイマー"""
    global InLedSt1
    global InLedSt2
    ret = TUSBSIN.Tusbs02in_Read(DevId)
    if ret[0] != 0: return
    if InLedSt1 != (ret[1]==1):
        InLedSt1 = (ret[1]==1)
        SetLEDCanvas(InLed1,InLedSt1)
    if InLedSt2 != (ret[2]==1):
        InLedSt2 = (ret[2]==1)
        SetLEDCanvas(InLed2,InLedSt2)

# Event Handler -----------------------------
def OpenCloseBtn_on():
    """オープンクローズボタン押下"""
    global DevId
    global mon_t
    DevId = IDCmbb.current()
    if OpenCloseBtn['text'] == "DeviceOpen":
        ret = TUSBSIN.Tusbs02in_Device_Open(DevId)
        if ret != 0:
            ShowInfo(TUSBSIN.GetErrMessage(ret))
            return
        WidgetState('Open')
        mon_t = intTT(0.5,Monitor)
        mon_t.Start()
        OpenCloseBtn['text'] = "DeviceClose"
    else: # DeviceClose
        mon_t.Stop()
        TUSBSIN.Tusbs02in_Device_Close(DevId)
        WidgetState('Close')
        OpenCloseBtn['text'] = "DeviceOpen"

# form generation ---------------------------
form  = tk.Tk()
form.geometry('308x207')
form.title('TUSB-S02INx Sample Program')
form.attributes("-toolwindow",True)

# 見出しラベル
GetLabel(form,"In1",0.26,0.2)
GetLabel(form,"In2",0.66,0.2)

# LED風表示
InLed1 = GetLEDCanvas(form,0.30,0.4)
InLedSt1 = False
SetLEDCanvas(InLed1,InLedSt1)
InLed2 = GetLEDCanvas(form,0.70,0.4)
InLedSt2 = False
SetLEDCanvas(InLed2,InLedSt2)

#ID open close ###################
IDList = [str(i) for i in range(16)]
GetLabel(form,"ID",0.15,0.85)
IDCmbb = GetComboBox(form,IDList,0.2,0.25,0.85)
OpenCloseBtn = GetButton(form,"DeviceOpen",OpenCloseBtn_on,0.3,0.7,0.85)

# Start
WidgetState('Close')
form.mainloop()
